Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(24)

Unified Diff: chrome/browser/sync/glue/frontend_data_type_controller.h

Issue 10662035: [Sync] Put everything in sync/api into csync namespace (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Fix comments Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/sync/glue/frontend_data_type_controller.h
diff --git a/chrome/browser/sync/glue/frontend_data_type_controller.h b/chrome/browser/sync/glue/frontend_data_type_controller.h
index 65bd460574f23158d4f4b084d4bbcf2228ad8e44..f55b59b68d2527ec0ca70701c46adea2aeb4aa09 100644
--- a/chrome/browser/sync/glue/frontend_data_type_controller.h
+++ b/chrome/browser/sync/glue/frontend_data_type_controller.h
@@ -17,9 +17,15 @@
class Profile;
class ProfileSyncService;
class ProfileSyncComponentsFactory;
+
+namespace base {
+class TimeDelta;
+}
+
+namespace csync {
class SyncError;
+}
-namespace base { class TimeDelta; }
namespace browser_sync {
class AssociatorInterface;
@@ -33,7 +39,7 @@ class ChangeProcessor;
// syncable::ModelType type() const
// void CreateSyncComponents();
// NOTE: This class is deprecated! New sync datatypes should be using the
// SyncableService API and the UIDataTypeController instead.
// TODO(zea): Delete this once all types are on the new API.
class FrontendDataTypeController : public DataTypeController {
public:
@@ -83,7 +89,7 @@ class FrontendDataTypeController : public DataTypeController {
virtual void CleanUpState();
// Helper methods for cleaning up state an running the start callback.
- virtual void StartFailed(StartResult result, const SyncError& error);
+ virtual void StartFailed(StartResult result, const csync::SyncError& error);
virtual void FinishStart(StartResult result);
// Record association time.
« no previous file with comments | « chrome/browser/sync/glue/fake_generic_change_processor.cc ('k') | chrome/browser/sync/glue/frontend_data_type_controller.cc » ('j') | no next file with comments »
@@ -33,7 +39,7 @@ class ChangeProcessor;
// void CreateSyncComponents();
// NOTE: This class is deprecated! New sync datatypes should be using the
-// SyncableService API and the UIDataTypeController instead.
+// csync::SyncableService API and the UIDataTypeController instead.
// TODO(zea): Delete this once all types are on the new API.
class FrontendDataTypeController : public DataTypeController {

Powered by Google App Engine
This is Rietveld 408576698